/* 
 * Browshot API
 *
 * Take screenshots of any website in real time
 *
 * OpenAPI spec version: 1.16.0
 * Contact: support@browshot.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */

package swagger

import (
	"net/url"
	"strings"
	"os"
	"io/ioutil"
	"encoding/json"
)

type BatchApi struct {
	Configuration *Configuration
}

func NewBatchApi() *BatchApi {
	configuration := NewConfiguration()
	return &BatchApi{
		Configuration: configuration,
	}
}

func NewBatchApiWithBasePath(basePath string) *BatchApi {
	configuration := NewConfiguration()
	configuration.BasePath = basePath

	return &BatchApi{
		Configuration: configuration,
	}
}

/**
 * Requests thousands of screenshtos at once
 * Get hundreds or thousands of screenshots from a text file. You can use this API call or the dashboard. Unlike the other API calls, you must issue a POST request with the Content-Type \&quot;multipart/form-data\&quot; in order to upload the text file. The text file must contain the list of URLs to request, 1 URL per line. Failed screenshots will be tried up to 3 times before giving up. 
 *
 * @param instanceId instance ID to use
 * @param file text file to use
 * @param size screenshots size - \&quot;screen\&quot; (default) or \&quot;page\&quot;
 * @param name name of the batch
 * @param width thumbnail width.
 * @param height thumbnail height
 * @param delay number of seconds to wait after the page has loaded. This is used to let JavaScript run longer before taking the screenshot. Use delay&#x3D;0 to take screenshots faster.
 * @param flashDelay number of seconds to wait after the page has loaded if Flash elements are present. Use flash_delay&#x3D;0 to take screenshots faster.
 * @param screenWidth width of the browser window. For desktop browsers only.
 * @param screenHeight height of the browser window. For desktop browsers only. (Note: full-page screenshots can have a height of up to 15,000px)
 * @param priority assign priority to the screenshot (for private instances only)
 * @param referer use a custom referrer header - paid screenshots only
 * @param postData send a POST requests with post_data, useful for filling out forms - paid screenshots only
 * @param cookie set a cookie for the URL requested (see Custom POST Data, Referer and Cookie) Cookies should be separated by a ; - paid screenshots only
 * @param script URL of javascript file to execute after the page load event
 * @param details level of information available with screenshot/info
 * @param html saves the HTML of the rendered page which can be retrieved by the API call screenshot/html. This feature costs *1 credit* per screenshot.
 * @param maxWait maximum number of seconds to wait before triggering the PageLoad event. Note that delay will still be used. (default: 0 &#x3D; disabled)
 * @param headers any custom HTTP headers. (Not supported with Internet Explorer)
 * @param format image as PNG or JPEG
 * @param shots take multiple screenshots of the same page. This costs 1 additional credit for every 2 additional screenshots.
 * @param shotInterval number of seconds between 2 screenshots
 * @return []Batch
 */
func (a BatchApi) BatchCeatePost(instanceId int32, file *os.File, size string, name string, width int32, height int32, delay int32, flashDelay int32, screenWidth int32, screenHeight int32, priority int32, referer string, postData string, cookie string, script string, details int32, html int32, maxWait int32, headers string, format string, shots int32, shotInterval int32) ([]Batch, *APIResponse, error) {

	var localVarHttpMethod = strings.ToUpper("Post")
	// create path and map variables
	localVarPath := a.Configuration.BasePath + "/batch/ceate"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := make(map[string]string)
	var localVarPostBody interface{}
	var localVarFileName string
	var localVarFileBytes []byte
	// authentication '(apiKeyQuery)' required
	// set key with prefix in query string
	localVarQueryParams["key"] =  a.Configuration.GetAPIKeyWithPrefix("key")
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		localVarHeaderParams[key] = a.Configuration.DefaultHeader[key]
	}

	// to determine the Content-Type header
	localVarHttpContentTypes := []string{ "multipart/form-data",  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
		}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHttpHeaderAccept
	}
	localVarFormParams["instanceId"] = a.Configuration.APIClient.ParameterToString(instanceId, "")
	fbs, _ := ioutil.ReadAll(file)
	localVarFileBytes = fbs
	localVarFileName = file.Name()
	localVarFormParams["size"] = a.Configuration.APIClient.ParameterToString(size, "")
	localVarFormParams["name"] = a.Configuration.APIClient.ParameterToString(name, "")
	localVarFormParams["width"] = a.Configuration.APIClient.ParameterToString(width, "")
	localVarFormParams["height"] = a.Configuration.APIClient.ParameterToString(height, "")
	localVarFormParams["delay"] = a.Configuration.APIClient.ParameterToString(delay, "")
	localVarFormParams["flashDelay"] = a.Configuration.APIClient.ParameterToString(flashDelay, "")
	localVarFormParams["screenWidth"] = a.Configuration.APIClient.ParameterToString(screenWidth, "")
	localVarFormParams["screenHeight"] = a.Configuration.APIClient.ParameterToString(screenHeight, "")
	localVarFormParams["priority"] = a.Configuration.APIClient.ParameterToString(priority, "")
	localVarFormParams["referer"] = a.Configuration.APIClient.ParameterToString(referer, "")
	localVarFormParams["postData"] = a.Configuration.APIClient.ParameterToString(postData, "")
	localVarFormParams["cookie"] = a.Configuration.APIClient.ParameterToString(cookie, "")
	localVarFormParams["script"] = a.Configuration.APIClient.ParameterToString(script, "")
	localVarFormParams["details"] = a.Configuration.APIClient.ParameterToString(details, "")
	localVarFormParams["html"] = a.Configuration.APIClient.ParameterToString(html, "")
	localVarFormParams["maxWait"] = a.Configuration.APIClient.ParameterToString(maxWait, "")
	localVarFormParams["headers"] = a.Configuration.APIClient.ParameterToString(headers, "")
	localVarFormParams["format"] = a.Configuration.APIClient.ParameterToString(format, "")
	localVarFormParams["shots"] = a.Configuration.APIClient.ParameterToString(shots, "")
	localVarFormParams["shotInterval"] = a.Configuration.APIClient.ParameterToString(shotInterval, "")
	var successPayload = new([]Batch)
	localVarHttpResponse, err := a.Configuration.APIClient.CallAPI(localVarPath, localVarHttpMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, localVarFileName, localVarFileBytes)

	var localVarURL, _ = url.Parse(localVarPath)
	localVarURL.RawQuery = localVarQueryParams.Encode()
	var localVarAPIResponse = &APIResponse{Operation: "BatchCeatePost", Method: localVarHttpMethod, RequestURL: localVarURL.String()}
	if localVarHttpResponse != nil {
		localVarAPIResponse.Response = localVarHttpResponse.RawResponse
		localVarAPIResponse.Payload = localVarHttpResponse.Body()
	}

	if err != nil {
		return *successPayload, localVarAPIResponse, err
	}
	err = json.Unmarshal(localVarHttpResponse.Body(), &successPayload)
	return *successPayload, localVarAPIResponse, err
}

/**
 * Get the batch status
 * Get the status of a batch requested through the API or through the dashboard. 
 *
 * @param id batch ID
 * @return *Batch
 */
func (a BatchApi) BatchInfoGet(id int32) (*Batch, *APIResponse, error) {

	var localVarHttpMethod = strings.ToUpper("Get")
	// create path and map variables
	localVarPath := a.Configuration.BasePath + "/batch/info"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := make(map[string]string)
	var localVarPostBody interface{}
	var localVarFileName string
	var localVarFileBytes []byte
	// authentication '(apiKeyQuery)' required
	// set key with prefix in query string
	localVarQueryParams["key"] =  a.Configuration.GetAPIKeyWithPrefix("key")
	// add default headers if any
	for key := range a.Configuration.DefaultHeader {
		localVarHeaderParams[key] = a.Configuration.DefaultHeader[key]
	}
	localVarQueryParams.Add("id", a.Configuration.APIClient.ParameterToString(id, ""))

	// to determine the Content-Type header
	localVarHttpContentTypes := []string{  }

	// set Content-Type header
	localVarHttpContentType := a.Configuration.APIClient.SelectHeaderContentType(localVarHttpContentTypes)
	if localVarHttpContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHttpContentType
	}
	// to determine the Accept header
	localVarHttpHeaderAccepts := []string{
		"application/json",
		}

	// set Accept header
	localVarHttpHeaderAccept := a.Configuration.APIClient.SelectHeaderAccept(localVarHttpHeaderAccepts)
	if localVarHttpHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHttpHeaderAccept
	}
	var successPayload = new(Batch)
	localVarHttpResponse, err := a.Configuration.APIClient.CallAPI(localVarPath, localVarHttpMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, localVarFileName, localVarFileBytes)

	var localVarURL, _ = url.Parse(localVarPath)
	localVarURL.RawQuery = localVarQueryParams.Encode()
	var localVarAPIResponse = &APIResponse{Operation: "BatchInfoGet", Method: localVarHttpMethod, RequestURL: localVarURL.String()}
	if localVarHttpResponse != nil {
		localVarAPIResponse.Response = localVarHttpResponse.RawResponse
		localVarAPIResponse.Payload = localVarHttpResponse.Body()
	}

	if err != nil {
		return successPayload, localVarAPIResponse, err
	}
	err = json.Unmarshal(localVarHttpResponse.Body(), &successPayload)
	return successPayload, localVarAPIResponse, err
}

